Class: BaseController

Inherits:
Object
  • Object
show all
Defined in:
app/controllers/base_controller.rb

Overview

The MIT License (MIT)

Copyright © 2019-2022 Kondratev Ilya

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the “Software”), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED “AS IS”, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

Direct Known Subclasses

ServicesController

Instance Method Summary collapse

Constructor Details

#initialize(request) ⇒ BaseController

Returns a new instance of BaseController.



24
25
26
27
# File 'app/controllers/base_controller.rb', line 24

def initialize(request)
  @request = request
  @response = Services::ProfileService.new
end

Instance Method Details

#not_foundObject



29
30
31
# File 'app/controllers/base_controller.rb', line 29

def not_found
  build_response("not_found", status: 404)
end